@@ -44,7 +44,8 @@ makeZDT2Function = function(dimensions) {
       upper = rep(1, dimensions),
       vector = TRUE
       ),
-    n.objectives = 2L
+    n.objectives = 2L,
+    ref.point = c(11, 11)
   )
 }
 
