@@ -14,7 +14,9 @@
 makeBukinN2Function = function() {
   makeSingleObjectiveFunction(
     name = "Bukin Function N. 2",
+    id = "bukin02_2d",
     fn = function(x) {
+      assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE)
       100 * (x[2] - 0.01 * x[1]^2 + 1) + 0.01 * (x[1] + 10)^2
     },
     par.set = makeNumericParamSet(
@@ -31,6 +33,6 @@ makeBukinN2Function = function() {
 }
 
 class(makeBukinN2Function) = c("function", "smoof_generator")
-attr(makeBukinN2Function, "name") = c("Bukin Function N. 2")
+attr(makeBukinN2Function, "name") = c("Bukin N. 2")
 attr(makeBukinN2Function, "type") = c("single-objective")
-attr(makeBukinN2Function, "tags") = c("continuous", "differentiable", "non-separable", "non-scalable", "multimodal")
+attr(makeBukinN2Function, "tags") = c("single-objective", "continuous", "differentiable", "non-separable", "non-scalable", "multimodal")
