@@ -14,10 +14,13 @@
 makeDixonPriceFunction = function(dimensions) {
   assertCount(dimensions)
   i = 1:dimensions
+  force(dimensions)
   global.opt.params = 2^((-1) * (2^i - 2) / 2^i)
   makeSingleObjectiveFunction(
     name = paste(dimensions, "-d Dixon-Price function", sep = ""),
+    id = paste0("dixonPrice_", dimensions, "d"),
     fn = function(x) {
+      assertNumeric(x, len = dimensions, any.missing = FALSE, all.missing = FALSE)
       a = (x[1] - 1)^2
       i = 2:length(x)
       b = sum(i * (2 * x[i]^2 - x[i - 1])^2)
@@ -37,6 +40,6 @@ makeDixonPriceFunction = function(dimensions) {
 }
 
 class(makeDixonPriceFunction) = c("function", "smoof_generator")
-attr(makeDixonPriceFunction, "name") = c("Dixon-Price Function")
+attr(makeDixonPriceFunction, "name") = c("Dixon-Price")
 attr(makeDixonPriceFunction, "type") = c("single-objective")
-attr(makeDixonPriceFunction, "tags") = c("continuous", "differentiable", "non-separable", "scalable", "unimodal")
+attr(makeDixonPriceFunction, "tags") = c("single-objective", "continuous", "differentiable", "non-separable", "scalable", "unimodal")
